@@ -36,7 +36,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaAppIdInfo", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaAppIdInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaAppIdInfoResponse()
@@ -64,7 +65,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaData", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaDataResponse()
@@ -92,7 +94,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaDataSum", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaDataSum", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaDataSumResponse()
@@ -120,7 +123,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaMiniData", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaMiniData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaMiniDataResponse()
@@ -148,7 +152,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaMiniDataSum", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaMiniDataSum", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaMiniDataSumResponse()
@@ -176,7 +181,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaMiniOperData", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaMiniOperData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaMiniOperDataResponse()
@@ -204,7 +210,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaMiniResult", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaMiniResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaMiniResultResponse()
@@ -232,7 +239,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaMiniRiskResult", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaMiniRiskResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaMiniRiskResultResponse()
@@ -260,7 +268,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaOperData", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaOperData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaOperDataResponse()
@@ -288,7 +297,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaResult", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaResultResponse()
@@ -316,7 +326,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaTicketData", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaTicketData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaTicketDataResponse()
@@ -344,7 +355,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCaptchaUserAllAppId", params)
+            headers = request.headers
+            body = self.call("DescribeCaptchaUserAllAppId", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCaptchaUserAllAppIdResponse()
@@ -362,6 +374,64 @@ class CaptchaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetTicketStatistics(self, request):
+        """查询单个CaptchaAppID票据校验数据，包括：票据校验量、票据校验通过量、票据校验拦截量。
+
+        :param request: Request instance for GetTicketStatistics.
+        :type request: :class:`tencentcloud.captcha.v20190722.models.GetTicketStatisticsRequest`
+        :rtype: :class:`tencentcloud.captcha.v20190722.models.GetTicketStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetTicketStatistics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetTicketStatisticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def GetTotalTicketStatistics(self, request):
+        """查询全部票据校验的统计数据，包括：总票据校验量、总票据校验通过量、总票据校验拦截量。
+
+        :param request: Request instance for GetTotalTicketStatistics.
+        :type request: :class:`tencentcloud.captcha.v20190722.models.GetTotalTicketStatisticsRequest`
+        :rtype: :class:`tencentcloud.captcha.v20190722.models.GetTotalTicketStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetTotalTicketStatistics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetTotalTicketStatisticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateCaptchaAppIdInfo(self, request):
         """更新验证码应用APPId信息
 
@@ -372,7 +442,8 @@ class CaptchaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateCaptchaAppIdInfo", params)
+            headers = request.headers
+            body = self.call("UpdateCaptchaAppIdInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateCaptchaAppIdInfoResponse()
